(shell project & cmd)Calls a shell command from Leiningen. Use it to add make or similar commands
to prep-tasks when no Leiningen plugin exists. If the process returns a nonzero
exit code, this command forces Leiningen to exit with the same exit code.
Call through lein shell cmd arg1 arg2 ... arg_n.
Calls a shell command from Leiningen. Use it to add `make` or similar commands to prep-tasks when no Leiningen plugin exists. If the process returns a nonzero exit code, this command forces Leiningen to exit with the same exit code. Call through `lein shell cmd arg1 arg2 ... arg_n`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |