Clojure only.

leiningen.shell


shellclj

(shell project & cmd)

For shelling out from Leiningen. Useful for adding stuff to prep-tasks like make or similar commands, which currently has no Leiningen plugin. If the process returns a nonzero exit code, this command will force Leiningen to exit with the same exit code.

Call through lein shell cmd arg1 arg2 ... arg_n.

For shelling out from Leiningen. Useful for adding stuff to prep-tasks like
`make` or similar commands, which currently has no Leiningen plugin. If the
process returns a nonzero exit code, this command will force Leiningen to exit
with the same exit code.

Call through `lein shell cmd arg1 arg2 ... arg_n`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries